Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
toml_parser_messages.ml1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46(* This file was auto-generated based on "toml_parser.messages". *) (* Please note that the function [message] can raise [Not_found]. *) let message = fun s -> match s with | 5 -> "Unexpected table header end.\n" | 45 -> "Invalid syntax.\n" | 46 -> "Invalid syntax (state 46).\n" | 7 -> "Extra closing ']' in a table header, or a missing opening '[' in a table array header.\nExample of a valid table header: [table]\nExample of a valid table array header: [[array_of_tables]]\n" | 0 -> "Unexpected ']' \n" | 13 -> "Unexpected '[' (too many opening square brackets in a table array header?)\n" | 14 -> "Missing closing '] in a table array header, or an extra opening '[' in a table header.\nExample of a valid table header: [table]\nExample of a valid table array header: [[array_of_tables]]\n" | 1 -> "Unexpected ']'\n" | 10 -> "Key is followed by end of file or a malformed TOML construct.\n" | 16 -> "Unexpected ']' (missing opening square bracket?)\n" | 17 -> "Malformed key-value pair (missing value?)\n" | 24 -> "Malformed inline table (missing closing brace?)\n" | 28 -> "Invalid syntax (state 28)\n" | 29 -> "Invalid syntax (state 29)\n" | 34 -> "Malformed array (missing closing square bracket?)\n" | 36 -> "Malformed array (missing closing square bracket?)\n" | 37 -> "Malformed array (missing closing square bracket?)\n" | 11 -> "Unexpected '.' in a key.\nExamples of valid keys: \"value\", \"table.subtable\", \"table.subtable.value\"\n" | _ -> raise Not_found